@@ -1,27 +1,39 @@
-import re
-from django import template
-from django.template.loader import render_to_string
-from django.utils import timezone
-from django.utils.translation import ugettext as _
-from django.core.urlresolvers import reverse
-from django.contrib.sessions.models import Session
-from modoboa.lib import events
+"""Custom tags for Core application."""
 
+import os
+import re
+from functools import reduce
+
+import pkg_resources
+
+from django import template
+from django.conf import settings
+from django.contrib.sessions.models import Session
+from django.template.loader import render_to_string
+from django.urls import reverse
+from django.utils import timezone
+from django.utils.encoding import smart_text
+from django.utils.safestring import mark_safe
+from django.utils.translation import get_language, ugettext as _
+
+from .. import models
+from .. import signals
 
 register = template.Library()
 
 
 @register.simple_tag
 def core_menu(selection, user):
-    entries = \
-        events.raiseQueryEvent("AdminMenuDisplay", "top_menu", user)
+    """Build the top level menu."""
+    entries = signals.extra_admin_menu_entries.send(
+        sender="core_menu", location="top_menu", user=user)
+    entries = reduce(lambda a, b: a + b, [entry[1] for entry in entries])
     if user.is_superuser:
         entries += [
             {"name": "settings",
              "label": _("Modoboa"),
              "url": reverse("core:index")}
         ]
-
     if not len(entries):
         return ""
     return render_to_string("common/menulist.html", {
@@ -33,8 +45,10 @@ def core_menu(selection, user):
 
 @register.simple_tag
 def extensions_menu(selection, user):
-    menu = events.raiseQueryEvent("UserMenuDisplay", "top_menu", user)
-    return render_to_string('common/menulist.html', {
+    menu = signals.extra_user_menu_entries.send(
+        sender="core_menu", location="top_menu", user=user)
+    menu = reduce(lambda a, b: a + b, [entry[1] for entry in menu])
+    return render_to_string("common/menulist.html", {
         "selection": selection, "entries": menu, "user": user
     })
 
@@ -42,11 +56,6 @@ def extensions_menu(selection, user):
 @register.simple_tag
 def admin_menu(selection, user):
     entries = [
-        {"name": "extensions",
-         "class": "ajaxnav",
-         "url": "extensions/",
-         "label": _("Extensions"),
-         "img": ""},
         {"name": "info",
          "class": "ajaxnav",
          "url": "info/",
@@ -61,7 +70,7 @@ def admin_menu(selection, user):
          "img": "",
          "label": _("Parameters")},
     ]
-    return render_to_string('common/menu.html', {
+    return render_to_string("common/menu.html", {
         "entries": entries,
         "css": "nav nav-sidebar",
         "selection": selection,
@@ -83,13 +92,16 @@ def user_menu(user, selection):
          ]}
     ]
 
-    entries[0]["menu"] += \
-        events.raiseQueryEvent("UserMenuDisplay", "options_menu", user) \
-        + [{"name": "logout",
-            "url": reverse("core:logout"),
-            "label": _("Logout"),
-            "img": "fa fa-sign-out"}]
-
+    extra_entries = signals.extra_user_menu_entries.send(
+        sender="user_menu", location="options_menu", user=user)
+    extra_entries = reduce(
+        lambda a, b: a + b, [entry[1] for entry in extra_entries])
+    entries[0]["menu"] += (
+        extra_entries + [{"name": "logout",
+                          "url": reverse("core:logout"),
+                          "label": _("Logout"),
+                          "img": "fa fa-sign-out"}]
+    )
     return render_to_string("common/menulist.html", {
         "selection": selection, "entries": entries, "user": user
     })
@@ -107,9 +119,20 @@ def uprefs_menu(selection, user):
          "url": "preferences/",
          "label": _("Preferences")},
     ]
-    entries += events.raiseQueryEvent("UserMenuDisplay", "uprefs_menu", user)
+    if user.is_superuser:
+        entries.append({
+            "name": "api",
+            "class": "ajaxnav",
+            "url": "api/",
+            "label": _("API"),
+        })
+    extra_entries = signals.extra_user_menu_entries.send(
+        sender="user_menu", location="uprefs_menu", user=user)
+    extra_entries = reduce(
+        lambda a, b: a + b, [entry[1] for entry in extra_entries])
+    entries += extra_entries
     entries = sorted(entries, key=lambda e: e["label"])
-    return render_to_string('common/menu.html', {
+    return render_to_string("common/menu.html", {
         "entries": entries,
         "css": "nav nav-sidebar",
         "selection": selection,
@@ -125,7 +148,7 @@ def colorize_level(level):
         "WARNING": "text-warning",
         "CRITICAL": "text-danger"
     }
-    if not level in classes:
+    if level not in classes:
         return level
     return "<p class='%s'>%s</p>" % (classes[level], level)
 
@@ -133,50 +156,45 @@ def colorize_level(level):
 @register.filter
 def tohtml(message):
     """Simple tag to format a text using HTML."""
-    return re.sub(r"'(.*?)'", "<strong>\g<1></strong>", message)
+    return re.sub(r"'(.*?)'", r"<strong>\g<1></strong>", message)
 
 
 @register.simple_tag
 def visirule(field):
-    if not hasattr(field, 'form') or \
+    if not hasattr(field, "form") or \
             not hasattr(field.form, "visirules") or \
-            not field.html_name in field.form.visirules:
+            field.html_name not in field.form.visirules:
         return ""
     rule = field.form.visirules[field.html_name]
-    return " data-visibility-field='%s' data-visibility-value='%s' " \
-        % (rule["field"], rule["value"])
+    return mark_safe(
+        " data-visibility-field='{}' data-visibility-value='{}' "
+        .format(rule["field"], rule["value"]))
 
 
 @register.simple_tag
 def get_version():
-    import pkg_resources
     return pkg_resources.get_distribution("modoboa").version
 
 
 class ConnectedUsers(template.Node):
+
     def __init__(self, varname):
         self.varname = varname
 
     def render(self, context):
-        from modoboa.core.models import User
-
         sessions = Session.objects.filter(expire_date__gte=timezone.now())
         uid_list = []
         # Build a list of user ids from that query
         for session in sessions:
             data = session.get_decoded()
-            uid = data.get('_auth_user_id', None)
+            uid = data.get("_auth_user_id", None)
             if uid:
                 uid_list.append(uid)
 
         # Query all logged in users based on id list
-        context[self.varname] = []
-        for uid in uid_list:
-            try:
-                context[self.varname].append(User.objects.get(pk=uid))
-            except User.DoesNotExist:
-                pass
-        return ''
+        context[self.varname] = (
+            models.User.objects.filter(pk__in=uid_list).distinct())
+        return ""
 
 
 @register.tag
@@ -185,16 +203,13 @@ def connected_users(parser, token):
         tag, a, varname = token.split_contents()
     except ValueError:
         raise template.TemplateSyntaxError(
-            'connected_users usage: {% connected_users as users %}'
+            "connected_users usage: {% connected_users as users %}"
         )
     return ConnectedUsers(varname)
 
 
 @register.simple_tag
 def get_modoboa_logo():
-    import os
-    from django.conf import settings
-
     try:
         logo = settings.MODOBOA_CUSTOM_LOGO
     except AttributeError:
@@ -206,9 +221,12 @@ def get_modoboa_logo():
 
 @register.simple_tag
 def load_optionalmenu(user):
-    menu = events.raiseQueryEvent("UserMenuDisplay", "top_menu_middle", user)
+    menu = signals.extra_user_menu_entries.send(
+        sender="user_menu", location="top_menu_middle", user=user)
+    menu = reduce(
+        lambda a, b: a + b, [entry[1] for entry in menu])
     return template.loader.render_to_string(
-        'common/menulist.html',
+        "common/menulist.html",
         {"entries": menu, "user": user}
     )
 
@@ -219,7 +237,7 @@ def display_messages(msgs):
     level = "info"
     for m in msgs:
         level = m.tags
-        text += unicode(m) + "\\\n"
+        text += smart_text(m) + "\\\n"
 
     if level == "info":
         level = "success"
@@ -227,10 +245,19 @@ def display_messages(msgs):
     else:
         timeout = "undefined"
 
-    return """
+    return mark_safe("""
 <script type="text/javascript">
     $(document).ready(function() {
         $('body').notify('%s', '%s', %s);
     });
 </script>
-""" % (level, text, timeout)
+""" % (level, text, timeout))
+
+
+@register.filter
+def currencyfmt(amount):
+    """Simple temp. filter to replace babel."""
+    lang = get_language()
+    if lang == "fr":
+        return u"{} €".format(amount)
+    return u"€{}".format(amount)
